<TS language="af" version="2.1">
<context>
    <name>AddressBookPage</name>
    <message>
        <source>Right-click to edit address or label</source>
        <translation>Regsklik om adres of etiket te verander</translation>
    </message>
    <message>
        <source>Create a new address</source>
        <translation>Skep ’n nuwe adres</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Nuwe</translation>
    </message>
    <message>
        <source>Copy the currently selected address to the system clipboard</source>
        <translation>Dupliseer die geselekteerde adres na die sisteem se geheuebord</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Dupliseer</translation>
    </message>
    <message>
        <source>C&amp;lose</source>
        <translation>S&amp;luit</translation>
    </message>
    <message>
        <source>Delete the currently selected address from the list</source>
        <translation>Verwyder die adres wat u gekies het van die lys</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Voer die inligting op hierdie bladsy uit na 'n leer</translation>
    </message>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Voer uit</translation>
    </message>
    <message>
        <source>&amp;Delete</source>
        <translation>&amp;Vee uit</translation>
    </message>
    <message>
        <source>Choose the address to send coins to</source>
        <translation>Kies die adres waarheen u munte wil stuur</translation>
    </message>
    <message>
        <source>Choose the address to receive coins with</source>
        <translation>Kies die adres wat die munte moet ontvang</translation>
    </message>
    <message>
        <source>C&amp;hoose</source>
        <translation>K&amp;ies</translation>
    </message>
    <message>
        <source>Sending addresses</source>
        <translation>Stuurders adresse</translation>
    </message>
    <message>
        <source>Receiving addresses</source>
        <translation>Ontvanger adresse</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for sending payments. Always check the amount and the receiving address before sending coins.</source>
        <translation>Hierdie is die adresse vanwaar u Litecoin betalings stuur. U moet altyd die bedrag en die adres van die ontvanger nagaan voordat u enige munte stuur.</translation>
    </message>
    <message>
        <source>These are your Litecoin addresses for receiving payments. It is recommended to use a new receiving address for each transaction.</source>
        <translation>Hierdie is die adresse waar u Litecoins sal ontvang. Ons beveel aan dat u 'n nuwe adres kies vir elke transaksie</translation>
    </message>
    <message>
        <source>&amp;Copy Address</source>
        <translation>&amp;Dupliseer Adres</translation>
    </message>
    <message>
        <source>Copy &amp;Label</source>
        <translation>Kopieer &amp;Etiket</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Verander</translation>
    </message>
    <message>
        <source>Export Address List</source>
        <translation>Voer adreslys uit</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma separated file (*.csv)</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Uitvoer was onsuksesvol</translation>
    </message>
    <message>
        <source>There was an error trying to save the address list to %1. Please try again.</source>
        <translation>Die adreslys kon nie in %1  gestoor word nie.  Probeer asseblief weer.</translation>
    </message>
</context>
<context>
    <name>AddressTableModel</name>
    <message>
        <source>Label</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
</context>
<context>
    <name>AskPassphraseDialog</name>
    <message>
        <source>Passphrase Dialog</source>
        <translation>Wagwoord Dialoog</translation>
    </message>
    <message>
        <source>Enter passphrase</source>
        <translation>Tik u wagwoord in</translation>
    </message>
    <message>
        <source>New passphrase</source>
        <translation>Nuwe wagwoord</translation>
    </message>
    <message>
        <source>Repeat new passphrase</source>
        <translation>Herhaal nuwe wagwoord</translation>
    </message>
    <message>
        <source>Show password</source>
        <translation>Wys wagwoord</translation>
    </message>
    <message>
        <source>Enter the new passphrase to the wallet.&lt;br/&gt;Please use a passphrase of &lt;b&gt;ten or more random characters&lt;/b&gt;, or &lt;b&gt;eight or more words&lt;/b&gt;.</source>
        <translation>Tik die nuwe wagwoord vir u beursie.&lt;br/&gt;Gerbuik asseblief 'n wagwoord met &lt;b&gt;tien of meer lukrake karakters&lt;/b&gt;, of &lt;b&gt;agt of meer woorde&lt;/b&gt;.</translation>
    </message>
    <message>
        <source>Encrypt wallet</source>
        <translation>Kodifiseer beursie</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to unlock the wallet.</source>
        <translation>U het u beursie se wagwoord nodig om toegang tot u beursie te verkry.</translation>
    </message>
    <message>
        <source>Unlock wallet</source>
        <translation>Sluit beursie oop</translation>
    </message>
    <message>
        <source>This operation needs your wallet passphrase to decrypt the wallet.</source>
        <translation>U het u beursie se wagwoord nodig om u beursie se kode te ontsyfer.</translation>
    </message>
    <message>
        <source>Decrypt wallet</source>
        <translation>Ontsleutel beursie</translation>
    </message>
    <message>
        <source>Change passphrase</source>
        <translation>Verander wagwoord</translation>
    </message>
    <message>
        <source>Enter the old passphrase and new passphrase to the wallet.</source>
        <translation>Tik die ou en die nuwe wagwoorde vir die beursie.</translation>
    </message>
    <message>
        <source>Confirm wallet encryption</source>
        <translation>Bevestig dat die beursie gekodifiseer is</translation>
    </message>
    <message>
        <source>Warning: If you encrypt your wallet and lose your passphrase, you will &lt;b&gt;LOSE ALL OF YOUR LITECOINS&lt;/b&gt;!</source>
        <translation>Waarskuwing: Indien u die beursie kodifiseer en u vergeet u wagwoord &lt;b&gt;VERLOOR U AL U LITECOINS&lt;/b&gt;!</translation>
    </message>
    <message>
        <source>Are you sure you wish to encrypt your wallet?</source>
        <translation>Is u seker dat u die beursie wil kodifiseer?</translation>
    </message>
    <message>
        <source>Wallet encrypted</source>
        <translation>Beursie gekodifiseer</translation>
    </message>
    <message>
        <source>IMPORTANT: Any previous backups you have made of your wallet file should be replaced with the newly generated, encrypted wallet file. For security reasons, previous backups of the unencrypted wallet file will become useless as soon as you start using the new, encrypted wallet.</source>
        <translation>BELANGRIK:  Alle vorige kopieë en rugsteun-weergawes wat u tevore van die gemaak het, moet vervang word met die jongste weergawe van u nuutste gekodifiseerde beursie.  Alle vorige weergawes en rugsteun-kopieë van u beursie sal nutteloos raak die oomblik wat u die nuut-gekodifiseerde beursie begin gebruik.</translation>
    </message>
    <message>
        <source>Wallet encryption failed</source>
        <translation>Kodifikasie was onsuksesvol</translation>
    </message>
    <message>
        <source>Wallet encryption failed due to an internal error. Your wallet was not encrypted.</source>
        <translation>Weens 'n interne fout het kodifikasie het nie geslaag nie.  U beursie is nie gekodifiseer nie</translation>
    </message>
    <message>
        <source>The supplied passphrases do not match.</source>
        <translation>Die wagwoorde stem nie ooreen nie.</translation>
    </message>
    <message>
        <source>Wallet unlock failed</source>
        <translation>Die beursie is nie oopgesluit nie</translation>
    </message>
    <message>
        <source>The passphrase entered for the wallet decryption was incorrect.</source>
        <translation>U het die verkeerde wagwoord ingetik.</translation>
    </message>
    <message>
        <source>Wallet decryption failed</source>
        <translation>Beursie-dekripsie het misluk</translation>
    </message>
    <message>
        <source>Wallet passphrase was successfully changed.</source>
        <translation>Beursie wagwoordfrase is suksesvol verander.</translation>
    </message>
    <message>
        <source>Warning: The Caps Lock key is on!</source>
        <translation>WAARSKUWING:  Outomatiese Kapitalisering is aktief op u sleutelbord!</translation>
    </message>
</context>
<context>
    <name>BanTableModel</name>
    <message>
        <source>IP/Netmask</source>
        <translation>IP/Netmasker</translation>
    </message>
    <message>
        <source>Banned Until</source>
        <translation>Verban tot</translation>
    </message>
</context>
<context>
    <name>BitcoinGUI</name>
    <message>
        <source>Sign &amp;message...</source>
        <translation>Teken &amp;boodskap...</translation>
    </message>
    <message>
        <source>Synchronizing with network...</source>
        <translation>Netwerk-sinkronisasie...</translation>
    </message>
    <message>
        <source>&amp;Overview</source>
        <translation>&amp;Oorsig</translation>
    </message>
    <message>
        <source>Show general overview of wallet</source>
        <translation>Vertoon 'n algemene oorsig van die beursie</translation>
    </message>
    <message>
        <source>&amp;Transactions</source>
        <translation>&amp;Transaksies</translation>
    </message>
    <message>
        <source>Browse transaction history</source>
        <translation>Blaai deur transaksiegeskiedenis</translation>
    </message>
    <message>
        <source>E&amp;xit</source>
        <translation>&amp;Sluit</translation>
    </message>
    <message>
        <source>Quit application</source>
        <translation>Stop en verlaat die applikasie</translation>
    </message>
    <message>
        <source>&amp;About %1</source>
        <translation>&amp;Oor %1</translation>
    </message>
    <message>
        <source>Show information about %1</source>
        <translation>Wys inligting oor %1</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Oor &amp;Qt</translation>
    </message>
    <message>
        <source>Show information about Qt</source>
        <translation>Wys inligting oor Qt</translation>
    </message>
    <message>
        <source>&amp;Options...</source>
        <translation>&amp;Opsies</translation>
    </message>
    <message>
        <source>Modify configuration options for %1</source>
        <translation>Verander konfigurasie-opsies vir %1</translation>
    </message>
    <message>
        <source>&amp;Encrypt Wallet...</source>
        <translation>&amp;Kodifiseer Beursie</translation>
    </message>
    <message>
        <source>&amp;Backup Wallet...</source>
        <translation>&amp;Rugsteun-kopie van Beursie</translation>
    </message>
    <message>
        <source>&amp;Change Passphrase...</source>
        <translation>&amp;Verander Wagwoord</translation>
    </message>
    <message>
        <source>Open &amp;URI...</source>
        <translation>Oop &amp; URI...</translation>
    </message>
    <message>
        <source>Click to disable network activity.</source>
        <translation>Kliek om netwerkaktiwiteit af te skakel.</translation>
    </message>
    <message>
        <source>Network activity disabled.</source>
        <translation>Netwerkaktiwiteit gedeaktiveer.</translation>
    </message>
    <message>
        <source>Click to enable network activity again.</source>
        <translation>Kliek om netwerkaktiwiteit weer aan te skakel.</translation>
    </message>
    <message>
        <source>Reindexing blocks on disk...</source>
        <translation>Besig met herindeksering van blokke op hardeskyf...</translation>
    </message>
    <message>
        <source>Send coins to a Litecoin address</source>
        <translation>Stuur munte na 'n Litecoin adres</translation>
    </message>
    <message>
        <source>Backup wallet to another location</source>
        <translation>Maak 'n rugsteun-kopié van beursie na 'n ander stoorplek</translation>
    </message>
    <message>
        <source>Change the passphrase used for wallet encryption</source>
        <translation>Verander die wagwoord wat ek vir kodifikasie van my beursie gebruik</translation>
    </message>
    <message>
        <source>&amp;Debug window</source>
        <translation>&amp;Ontfout venster</translation>
    </message>
    <message>
        <source>Open debugging and diagnostic console</source>
        <translation>Maak ontfouting en diagnostiese konsole oop</translation>
    </message>
    <message>
        <source>&amp;Verify message...</source>
        <translation>&amp;Verifieer boodskap...</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>&amp;Send</source>
        <translation>&amp;Stuur</translation>
    </message>
    <message>
        <source>&amp;Receive</source>
        <translation>&amp;Ontvang</translation>
    </message>
    <message>
        <source>&amp;Show / Hide</source>
        <translation>&amp;Wys / Versteek</translation>
    </message>
    <message>
        <source>Show or hide the main Window</source>
        <translation>Wys of versteek die hoofbladsy</translation>
    </message>
    <message>
        <source>Encrypt the private keys that belong to your wallet</source>
        <translation>Kodifiseer die private sleutes wat aan jou beursie gekoppel is.</translation>
    </message>
    <message>
        <source>Sign messages with your Litecoin addresses to prove you own them</source>
        <translation>Onderteken boodskappe met u Litecoin adresse om u eienaarskap te bewys</translation>
    </message>
    <message>
        <source>Verify messages to ensure they were signed with specified Litecoin addresses</source>
        <translation>Verifieër boodskappe om seker te maak dat dit met die gespesifiseerde Litecoin adresse</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Leër</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Verstellings</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>Tabs toolbar</source>
        <translation>Orebalk</translation>
    </message>
    <message>
        <source>Request payments (generates QR codes and litecoin: URIs)</source>
        <translation>Versoek betalings (genereer QR-kodes en litecoin: URI's)</translation>
    </message>
    <message>
        <source>Show the list of used sending addresses and labels</source>
        <translation>Vertoon die lys van gebruikte versendingsadresse en etikette</translation>
    </message>
    <message>
        <source>Show the list of used receiving addresses and labels</source>
        <translation>Vertoon die lys van gebruikte ontvangers-adresse en etikette</translation>
    </message>
    <message>
        <source>Open a litecoin: URI or payment request</source>
        <translation>Skep 'n litecoin: URI of betalingsversoek</translation>
    </message>
    <message>
        <source>&amp;Command-line options</source>
        <translation>&amp;Opdrag lyn opsies</translation>
    </message>
    <message>
        <source>Indexing blocks on disk...</source>
        <translation>Blokke op skyf word geïndekseer...</translation>
    </message>
    <message>
        <source>Processing blocks on disk...</source>
        <translation>Blokke op skyf word geprosesseer...</translation>
    </message>
    <message>
        <source>%1 behind</source>
        <translation>%1 agter</translation>
    </message>
    <message>
        <source>Last received block was generated %1 ago.</source>
        <translation>Laaste ontvange blok is %1 gelede gegenereer.</translation>
    </message>
    <message>
        <source>Transactions after this will not yet be visible.</source>
        <translation>Transaksies hierna sal nog nie sigbaar wees nie.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarskuwing</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Inligting</translation>
    </message>
    <message>
        <source>Up to date</source>
        <translation>Op datum</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <source>%1 client</source>
        <translation>%1 kliënt</translation>
    </message>
    <message>
        <source>Connecting to peers...</source>
        <translation>Koppel aan eweknieë...</translation>
    </message>
    <message>
        <source>Catching up...</source>
        <translation>Word op datum gebring...</translation>
    </message>
    <message>
        <source>Date: %1
</source>
        <translation>Datum: %1
</translation>
    </message>
    <message>
        <source>Amount: %1
</source>
        <translation>Bedrag: %1
</translation>
    </message>
    <message>
        <source>Type: %1
</source>
        <translation>Tipe: %1
</translation>
    </message>
    <message>
        <source>Label: %1
</source>
        <translation>Etiket: %1
</translation>
    </message>
    <message>
        <source>Address: %1
</source>
        <translation>Adres: %1
</translation>
    </message>
    <message>
        <source>Sent transaction</source>
        <translation>Gestuurde transaksie</translation>
    </message>
    <message>
        <source>Incoming transaction</source>
        <translation>Inkomende transaksie</translation>
    </message>
    <message>
        <source>A fatal error occurred. Litecoin can no longer continue safely and will quit.</source>
        <translation>'N fatale fout het voorgekom. Litecoin kan nie meer veilig voortgaan nie en sal nou toemaak.</translation>
    </message>
</context>
<context>
    <name>CoinControlDialog</name>
    <message>
        <source>Coin Selection</source>
        <translation>Munt Seleksie</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Grepe:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Stof:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Na Fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Verander:</translation>
    </message>
    <message>
        <source>(un)select all</source>
        <translation>(de)selekteer alle</translation>
    </message>
    <message>
        <source>Tree mode</source>
        <translation>Boom wyse</translation>
    </message>
    <message>
        <source>List mode</source>
        <translation>Lysmodus</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Received with label</source>
        <translation>Ontvang met etiket</translation>
    </message>
    <message>
        <source>Received with address</source>
        <translation>Ontvang met adres</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Confirmations</source>
        <translation>Bevestigings</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopieer adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transaksie ID</translation>
    </message>
    <message>
        <source>Lock unspent</source>
        <translation>Sluit ongespandeer</translation>
    </message>
    <message>
        <source>Unlock unspent</source>
        <translation>Ontsluit ongespandeer</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer grepe</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopieer stof</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer verandering</translation>
    </message>
    <message>
        <source>(%1 locked)</source>
        <translation>(%1 gesluit)</translation>
    </message>
    <message>
        <source>yes</source>
        <translation>ja</translation>
    </message>
    <message>
        <source>no</source>
        <translation>nee</translation>
    </message>
    <message>
        <source>This label turns red if any recipient receives an amount smaller than the current dust threshold.</source>
        <translation>Hierdie etiket raak rooi as enige ontvanger 'n bedrag kleiner as die huidige stof drempel ontvang.</translation>
    </message>
    <message>
        <source>Can vary +/- %1 satoshi(s) per input.</source>
        <translation>Kan verskil met +/- %1 satoshi(s) per invoer.</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    <message>
        <source>change from %1 (%2)</source>
        <translation>verander van %1 (%2)</translation>
    </message>
    <message>
        <source>(change)</source>
        <translation>(verander)</translation>
    </message>
</context>
<context>
    <name>EditAddressDialog</name>
    <message>
        <source>Edit Address</source>
        <translation>Wysig Adres</translation>
    </message>
    <message>
        <source>&amp;Label</source>
        <translation>&amp;Etiket</translation>
    </message>
    <message>
        <source>The label associated with this address list entry</source>
        <translation>Die etiket wat verband hou met hierdie adres lys inskrywing</translation>
    </message>
    <message>
        <source>The address associated with this address list entry. This can only be modified for sending addresses.</source>
        <translation>Die adres wat verband hou met hierdie adres lys inskrywing. Dit kan net verander word vir stuur adresse.</translation>
    </message>
    <message>
        <source>&amp;Address</source>
        <translation>&amp;Adres</translation>
    </message>
    <message>
        <source>New sending address</source>
        <translation>Nuwe stuur adres</translation>
    </message>
    <message>
        <source>Edit receiving address</source>
        <translation>Wysig ontvang adres</translation>
    </message>
    <message>
        <source>Edit sending address</source>
        <translation>Wysig stuur adres</translation>
    </message>
    <message>
        <source>The entered address "%1" is not a valid Litecoin address.</source>
        <translation>Die ingevoerde adres "%1" is nie 'n geldige Litecoin adres nie.</translation>
    </message>
    <message>
        <source>Could not unlock wallet.</source>
        <translation>Kon beursie nie oopsluit nie.</translation>
    </message>
    <message>
        <source>New key generation failed.</source>
        <translation>Nuwe sleutel generasie het misluk.</translation>
    </message>
</context>
<context>
    <name>FreespaceChecker</name>
    <message>
        <source>A new data directory will be created.</source>
        <translation>'N Nuwe data gids sal geskep word.</translation>
    </message>
    <message>
        <source>name</source>
        <translation>naam</translation>
    </message>
    <message>
        <source>Directory already exists. Add %1 if you intend to create a new directory here.</source>
        <translation>Gids bestaan reeds. Voeg %1 by indien u van plan is om 'n nuwe gids hier te skep.</translation>
    </message>
    <message>
        <source>Path already exists, and is not a directory.</source>
        <translation>Pad bestaan reeds, en is nie 'n gids nie.</translation>
    </message>
    <message>
        <source>Cannot create data directory here.</source>
        <translation>Kan hier nie data gids skep nie.</translation>
    </message>
</context>
<context>
    <name>HelpMessageDialog</name>
    <message>
        <source>version</source>
        <translation>weergawe</translation>
    </message>
    <message>
        <source>(%1-bit)</source>
        <translation>(%1-stukkie)</translation>
    </message>
    <message>
        <source>About %1</source>
        <translation>Ongeveer %1</translation>
    </message>
    <message>
        <source>Command-line options</source>
        <translation>Opdrag lyn opsies</translation>
    </message>
</context>
<context>
    <name>Intro</name>
    <message>
        <source>Welcome</source>
        <translation>Welkom</translation>
    </message>
    <message>
        <source>Welcome to %1.</source>
        <translation>Welkom by %1.</translation>
    </message>
    <message>
        <source>Use the default data directory</source>
        <translation>Gebruik die standaard data gids</translation>
    </message>
    <message>
        <source>Use a custom data directory:</source>
        <translation>Gebruik 'n persoonlike data gids:</translation>
    </message>
    <message>
        <source>Litecoin</source>
        <translation>Litecoin</translation>
    </message>
    <message>
        <source>The wallet will also be stored in this directory.</source>
        <translation>Die beursie sal ook in hierdie gids gestoor word.</translation>
    </message>
    <message>
        <source>Error: Specified data directory "%1" cannot be created.</source>
        <translation>Fout: Gespesifiseerde dataleêr "%1" kon nie geskep word nie.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    </context>
<context>
    <name>ModalOverlay</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Number of blocks left</source>
        <translation>Aantal blokke oor</translation>
    </message>
    <message>
        <source>Unknown...</source>
        <translation>Onbekend...</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Laaste blok tyd</translation>
    </message>
    <message>
        <source>Progress</source>
        <translation>Vordering</translation>
    </message>
    <message>
        <source>Progress increase per hour</source>
        <translation>Vorderingstoename per uur</translation>
    </message>
    <message>
        <source>calculating...</source>
        <translation>besig met bereken...</translation>
    </message>
    <message>
        <source>Estimated time left until synced</source>
        <translation>Geskatte tyd oor totdat gesinkroniseer</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Versteek</translation>
    </message>
    </context>
<context>
    <name>OpenURIDialog</name>
    <message>
        <source>Open URI</source>
        <translation>Open URI</translation>
    </message>
    <message>
        <source>Open payment request from URI or file</source>
        <translation>Open betaling versoek van URI of lêer</translation>
    </message>
    <message>
        <source>URI:</source>
        <translation>URI:</translation>
    </message>
    <message>
        <source>Select payment request file</source>
        <translation>Kies betaling versoek lêer</translation>
    </message>
    <message>
        <source>Select payment request file to open</source>
        <translation>Kies betaling versoek lêer om oop te maak</translation>
    </message>
</context>
<context>
    <name>OptionsDialog</name>
    <message>
        <source>Options</source>
        <translation>Opsies</translation>
    </message>
    <message>
        <source>&amp;Main</source>
        <translation>&amp;Hoof</translation>
    </message>
    <message>
        <source>Automatically start %1 after logging in to the system.</source>
        <translation>Begin %1 outomaties nadat jy aangemeld is by die stelsel.</translation>
    </message>
    <message>
        <source>&amp;Start %1 on system login</source>
        <translation>&amp;Begin %1 op stelsel aanmelding</translation>
    </message>
    <message>
        <source>Size of &amp;database cache</source>
        <translation>Grootte van &amp;databasis kas</translation>
    </message>
    <message>
        <source>Number of script &amp;verification threads</source>
        <translation>Aantal skrip &amp;verifikasie drade</translation>
    </message>
    <message>
        <source>Open the %1 configuration file from the working directory.</source>
        <translation>Maak die %1 konfigurasie lêer oop van die werk gids.</translation>
    </message>
    <message>
        <source>Open Configuration File</source>
        <translation>Open Konfigurasie Lêer</translation>
    </message>
    <message>
        <source>Reset all client options to default.</source>
        <translation>Alle kliëntopsies na verstek terugstel.</translation>
    </message>
    <message>
        <source>&amp;Reset Options</source>
        <translation>&amp;Herstel Opsies</translation>
    </message>
    <message>
        <source>&amp;Network</source>
        <translation>&amp;Netwerk</translation>
    </message>
    <message>
        <source>W&amp;allet</source>
        <translation>B&amp;eursie</translation>
    </message>
    <message>
        <source>Expert</source>
        <translation>Kenner</translation>
    </message>
    <message>
        <source>Enable coin &amp;control features</source>
        <translation>Bemagtig munt &amp;beheer funksies.</translation>
    </message>
    <message>
        <source>&amp;Spend unconfirmed change</source>
        <translation>&amp;Spandeer onbevestigde kleingeld</translation>
    </message>
    <message>
        <source>&amp;Port:</source>
        <translation>&amp;Poort:</translation>
    </message>
    <message>
        <source>Used for reaching peers via:</source>
        <translation>Word gebruik vir die bereik van eweknieë via:</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Tor</source>
        <translation>Tor</translation>
    </message>
    <message>
        <source>&amp;Window</source>
        <translation>&amp;Venster</translation>
    </message>
    <message>
        <source>M&amp;inimize on close</source>
        <translation>M&amp;inimaliseer op toemaak</translation>
    </message>
    <message>
        <source>&amp;Display</source>
        <translation>&amp;Vertoon</translation>
    </message>
    <message>
        <source>User Interface &amp;language:</source>
        <translation>Gebruikers Koppelvlak &amp;taal:</translation>
    </message>
    <message>
        <source>&amp;Unit to show amounts in:</source>
        <translation>&amp;Eenheid om bedrae te toon in:</translation>
    </message>
    <message>
        <source>Whether to show coin control features or not.</source>
        <translation>Of om munt beheer funksies te wys of nie.</translation>
    </message>
    <message>
        <source>&amp;OK</source>
        <translation>&amp;OK</translation>
    </message>
    <message>
        <source>&amp;Cancel</source>
        <translation>&amp;Kanselleer</translation>
    </message>
    <message>
        <source>default</source>
        <translation>verstek</translation>
    </message>
    <message>
        <source>none</source>
        <translation>geen</translation>
    </message>
    <message>
        <source>Confirm options reset</source>
        <translation>Bevestig terugstel van opsies</translation>
    </message>
    <message>
        <source>Client restart required to activate changes.</source>
        <translation>Kliënt moet herbegin word om veranderinge te aktiveer.</translation>
    </message>
    <message>
        <source>Client will be shut down. Do you want to proceed?</source>
        <translation>Kliënt sal toegemaak word. Wil u voortgaan?</translation>
    </message>
    <message>
        <source>Configuration options</source>
        <translation>Konfigurasie opsies</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>The configuration file could not be opened.</source>
        <translation>Die konfigurasie lêer kon nie oopgemaak word nie.</translation>
    </message>
    <message>
        <source>This change would require a client restart.</source>
        <translation>Hierdie verandering sal 'n herbegin van die kliënt vereis. </translation>
    </message>
    <message>
        <source>The supplied proxy address is invalid.</source>
        <translation>Die verskafde volmag adres is ongeldig.</translation>
    </message>
</context>
<context>
    <name>OverviewPage</name>
    <message>
        <source>Form</source>
        <translation>Vorm</translation>
    </message>
    <message>
        <source>Watch-only:</source>
        <translation>Kyk-net:</translation>
    </message>
    <message>
        <source>Available:</source>
        <translation>Beskikbaar:</translation>
    </message>
    <message>
        <source>Your current spendable balance</source>
        <translation>U huidige bruikbare balans</translation>
    </message>
    <message>
        <source>Pending:</source>
        <translation>Hangend:</translation>
    </message>
    <message>
        <source>Immature:</source>
        <translation>Onvolwasse:</translation>
    </message>
    <message>
        <source>Balances</source>
        <translation>Balanse</translation>
    </message>
    <message>
        <source>Total:</source>
        <translation>Totaal:</translation>
    </message>
    <message>
        <source>Your current total balance</source>
        <translation>U huidige totale balans</translation>
    </message>
    <message>
        <source>Spendable:</source>
        <translation>Besteebaar:</translation>
    </message>
    <message>
        <source>Recent transactions</source>
        <translation>Onlangse transaksies</translation>
    </message>
    </context>
<context>
    <name>PaymentServer</name>
    <message>
        <source>Payment request error</source>
        <translation>Betalings versoek fout</translation>
    </message>
    <message>
        <source>URI handling</source>
        <translation>URI hantering</translation>
    </message>
    <message>
        <source>Payment request rejected</source>
        <translation>Betalings versoek verwerp</translation>
    </message>
    <message>
        <source>Payment request network doesn't match client network.</source>
        <translation>Betalings versoek netwerk stem nie ooreen met die kliënt netwerk nie.</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Betalings versoek verstryk.</translation>
    </message>
    <message>
        <source>Payment request is not initialized.</source>
        <translation>Betalings versoek is nie geïnitialiseer nie.</translation>
    </message>
    <message>
        <source>Invalid payment request.</source>
        <translation>Ongeldige betalings versoek.</translation>
    </message>
    <message>
        <source>Refund from %1</source>
        <translation>Terugbetaling van %1</translation>
    </message>
    <message>
        <source>Error communicating with %1: %2</source>
        <translation>Kommunikerings fout met %1: %2</translation>
    </message>
    <message>
        <source>Payment request cannot be parsed!</source>
        <translation>Betalings versoek kan nie ontleed word nie!</translation>
    </message>
    <message>
        <source>Network request error</source>
        <translation>Netwerk versoek fout</translation>
    </message>
    </context>
<context>
    <name>PeerTableModel</name>
    <message>
        <source>User Agent</source>
        <translation>Gebruikeragent</translation>
    </message>
    <message>
        <source>NodeId</source>
        <translation>NodusId</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Gestuur</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Ontvang</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Enter a Litecoin address (e.g. %1)</source>
        <translation>Voer in 'n Litecoin adres (bv. %1)</translation>
    </message>
    <message>
        <source>%1 d</source>
        <translation>%1 d</translation>
    </message>
    <message>
        <source>%1 h</source>
        <translation>%1 u</translation>
    </message>
    <message>
        <source>%1 m</source>
        <translation>%1 m</translation>
    </message>
    <message>
        <source>%1 s</source>
        <translation>%1 s</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Geen</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>n.v.t.</translation>
    </message>
    <message>
        <source>%1 ms</source>
        <translation>%1 ms</translation>
    </message>
    <message>
        <source>%1 and %2</source>
        <translation>%1 en %2</translation>
    </message>
    <message>
        <source>%1 B</source>
        <translation>%1 B</translation>
    </message>
    <message>
        <source>%1 KB</source>
        <translation>%1 KB</translation>
    </message>
    <message>
        <source>%1 MB</source>
        <translation>%1 MB</translation>
    </message>
    <message>
        <source>%1 GB</source>
        <translation>%1 GB</translation>
    </message>
    </context>
<context>
    <name>QObject::QObject</name>
    <message>
        <source>Error: %1</source>
        <translation>Fout: %1</translation>
    </message>
</context>
<context>
    <name>QRImageWidget</name>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Stoor beeld</translation>
    </message>
    </context>
<context>
    <name>RPCConsole</name>
    <message>
        <source>N/A</source>
        <translation>n.v.t.</translation>
    </message>
    <message>
        <source>Client version</source>
        <translation>Kliëntweergawe</translation>
    </message>
    <message>
        <source>&amp;Information</source>
        <translation>&amp;Informasie</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Netwerk</translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Number of connections</source>
        <translation>Aantal verbindings</translation>
    </message>
    <message>
        <source>Block chain</source>
        <translation>Blokketting</translation>
    </message>
    <message>
        <source>Current number of blocks</source>
        <translation>Huidige aantal blokke</translation>
    </message>
    <message>
        <source>Received</source>
        <translation>Ontvang</translation>
    </message>
    <message>
        <source>Sent</source>
        <translation>Gestuur</translation>
    </message>
    <message>
        <source>Banned peers</source>
        <translation>Verbanne porture</translation>
    </message>
    <message>
        <source>Whitelisted</source>
        <translation>Gewitlys</translation>
    </message>
    <message>
        <source>Direction</source>
        <translation>Rigting</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>Weergawe</translation>
    </message>
    <message>
        <source>User Agent</source>
        <translation>Gebruikeragent</translation>
    </message>
    <message>
        <source>Last block time</source>
        <translation>Laaste blok tyd</translation>
    </message>
    <message>
        <source>In:</source>
        <translation>In:</translation>
    </message>
    <message>
        <source>Out:</source>
        <translation>Uit:</translation>
    </message>
    <message>
        <source>1 &amp;hour</source>
        <translation>1 &amp;uur</translation>
    </message>
    <message>
        <source>1 &amp;day</source>
        <translation>1 &amp;dag</translation>
    </message>
    <message>
        <source>1 &amp;week</source>
        <translation>1 &amp;week</translation>
    </message>
    <message>
        <source>1 &amp;year</source>
        <translation>1 &amp;jaar</translation>
    </message>
    <message>
        <source>&amp;Disconnect</source>
        <translation>&amp;Ontkoppel</translation>
    </message>
    <message>
        <source>Ban for</source>
        <translation>Verbied vir</translation>
    </message>
    <message>
        <source>&amp;Unban</source>
        <translation>&amp;Toegelaat</translation>
    </message>
    <message>
        <source>Network activity disabled</source>
        <translation>Netwerk aktiewiteit gedeaktiveer</translation>
    </message>
    <message>
        <source>(node id: %1)</source>
        <translation>(nodus id: %1)</translation>
    </message>
    <message>
        <source>via %1</source>
        <translation>via %1</translation>
    </message>
    <message>
        <source>never</source>
        <translation>nooit</translation>
    </message>
    <message>
        <source>Inbound</source>
        <translation>Inkomende</translation>
    </message>
    <message>
        <source>Outbound</source>
        <translation>Uitgaande</translation>
    </message>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
    <message>
        <source>No</source>
        <translation>Nee</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>Onbekend</translation>
    </message>
</context>
<context>
    <name>ReceiveCoinsDialog</name>
    <message>
        <source>&amp;Amount:</source>
        <translation>&amp;Bedrag</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiket:</translation>
    </message>
    <message>
        <source>&amp;Message:</source>
        <translation>&amp;Boodslap:</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Vee alle velde op die vorm skoon</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Skoonmaak</translation>
    </message>
    <message>
        <source>&amp;Request payment</source>
        <translation>&amp;Versoek betaling</translation>
    </message>
    <message>
        <source>Show</source>
        <translation>Wys</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwyder</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer etiket</translation>
    </message>
    <message>
        <source>Copy message</source>
        <translation>Kopieer boodskap</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
</context>
<context>
    <name>ReceiveRequestDialog</name>
    <message>
        <source>QR Code</source>
        <translation>QR Kode</translation>
    </message>
    <message>
        <source>Copy &amp;URI</source>
        <translation>Kopieer &amp;URI</translation>
    </message>
    <message>
        <source>Copy &amp;Address</source>
        <translation>Kopieer &amp;Address</translation>
    </message>
    <message>
        <source>&amp;Save Image...</source>
        <translation>&amp;Stoor beeld</translation>
    </message>
    <message>
        <source>Request payment to %1</source>
        <translation>Versoek betaling van %1</translation>
    </message>
    <message>
        <source>Payment information</source>
        <translation>Betaling informasie</translation>
    </message>
    <message>
        <source>URI</source>
        <translation>URI</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Wallet</source>
        <translation>Beursie</translation>
    </message>
    <message>
        <source>Resulting URI too long, try to reduce the text for label / message.</source>
        <translation>Gevolglike URI te lank, probeer teks verkort vir etiket/boodskap</translation>
    </message>
    <message>
        <source>Error encoding URI into QR Code.</source>
        <translation>Fout met enkodering van URI na QR kode</translation>
    </message>
</context>
<context>
    <name>RecentRequestsTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    <message>
        <source>(no message)</source>
        <translation>(geen boodskap)</translation>
    </message>
    <message>
        <source>(no amount requested)</source>
        <translation>(geen bedrag versoek)</translation>
    </message>
    <message>
        <source>Requested</source>
        <translation>Versoekte</translation>
    </message>
</context>
<context>
    <name>SendCoinsDialog</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munte</translation>
    </message>
    <message>
        <source>Coin Control Features</source>
        <translation>Munt Beheer Kenmerke</translation>
    </message>
    <message>
        <source>Inputs...</source>
        <translation>Insette...</translation>
    </message>
    <message>
        <source>automatically selected</source>
        <translation>outomaties gekies</translation>
    </message>
    <message>
        <source>Insufficient funds!</source>
        <translation>Onvoldoende fondse!</translation>
    </message>
    <message>
        <source>Quantity:</source>
        <translation>Hoeveelheid:</translation>
    </message>
    <message>
        <source>Bytes:</source>
        <translation>Grepe:</translation>
    </message>
    <message>
        <source>Amount:</source>
        <translation>Bedrag:</translation>
    </message>
    <message>
        <source>Fee:</source>
        <translation>Fooi:</translation>
    </message>
    <message>
        <source>After Fee:</source>
        <translation>Na Fooi:</translation>
    </message>
    <message>
        <source>Change:</source>
        <translation>Verander:</translation>
    </message>
    <message>
        <source>Transaction Fee:</source>
        <translation>Transaksiefooi:</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Kies...</translation>
    </message>
    <message>
        <source>Using the fallbackfee can result in sending a transaction that will take several hours or days (or never) to confirm. Consider choosing your fee manually or wait until you have validated the complete chain.</source>
        <translation>Die verstekfooi kan veroorsaak dat 'n transaksie gestuur word wat
etlike ure of dae (of nooit) sal neem om te bevestig. Oorweeg om 
'n fooi met die hand te kies, of wag tot jy die hele ketting bevestig het.</translation>
    </message>
    <message>
        <source>Warning: Fee estimation is currently not possible.</source>
        <translation>Waarskuwing: fooiskatting is tans onbeskikbaar</translation>
    </message>
    <message>
        <source>collapse fee-settings</source>
        <translation>Vou fooi-nistellings in</translation>
    </message>
    <message>
        <source>per kilobyte</source>
        <translation>per kilogreep</translation>
    </message>
    <message>
        <source>Hide</source>
        <translation>Versteek</translation>
    </message>
    <message>
        <source>Recommended:</source>
        <translation>Aanbeveel:</translation>
    </message>
    <message>
        <source>Custom:</source>
        <translation>Aangepaste:</translation>
    </message>
    <message>
        <source>(Smart fee not initialized yet. This usually takes a few blocks...)</source>
        <translation>(Slimfooi nog nie opgestel nie. Dit neem gewoonlik 'n paar blokke...)</translation>
    </message>
    <message>
        <source>Send to multiple recipients at once</source>
        <translation>Stuur aan veelvuldige ontvangers tegelyk</translation>
    </message>
    <message>
        <source>Add &amp;Recipient</source>
        <translation>Voeg by &amp;Ontvanger</translation>
    </message>
    <message>
        <source>Clear all fields of the form.</source>
        <translation>Vee alle velde op die vorm skoon</translation>
    </message>
    <message>
        <source>Dust:</source>
        <translation>Stof:</translation>
    </message>
    <message>
        <source>Confirmation time target:</source>
        <translation>Bevestigingstyd teiken:</translation>
    </message>
    <message>
        <source>Enable Replace-By-Fee</source>
        <translation>Bemoontlik vervang-deur-fooi</translation>
    </message>
    <message>
        <source>With Replace-By-Fee (BIP-125) you can increase a transaction's fee after it is sent. Without this, a higher fee may be recommended to compensate for increased transaction delay risk.</source>
        <translation>Met Vervang-Met-Fooi (BIP-125) kan jy 'n transaskiefooi verhoog nadat dit gestuur is.
Daarsonder mag 'n hoër fooi dalk aanbeveel word om te kompenseer vir 'n verhoogde
transaksievertragingsrisiko.</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vee &amp;Alles skoon</translation>
    </message>
    <message>
        <source>Balance:</source>
        <translation>Saldo:</translation>
    </message>
    <message>
        <source>Confirm the send action</source>
        <translation>Bevestig stuuraksie</translation>
    </message>
    <message>
        <source>S&amp;end</source>
        <translation>S&amp;tuur</translation>
    </message>
    <message>
        <source>Copy quantity</source>
        <translation>Kopieer hoeveelheid</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy fee</source>
        <translation>Kopieer fooi</translation>
    </message>
    <message>
        <source>Copy after fee</source>
        <translation>Kopieer na fooi</translation>
    </message>
    <message>
        <source>Copy bytes</source>
        <translation>Kopieer grepe</translation>
    </message>
    <message>
        <source>Copy dust</source>
        <translation>Kopieer stof</translation>
    </message>
    <message>
        <source>Copy change</source>
        <translation>Kopieer verandering</translation>
    </message>
    <message>
        <source>%1 (%2 blocks)</source>
        <translation>%1 (%2 blokke)</translation>
    </message>
    <message>
        <source>%1 to %2</source>
        <translation>%1 tot %2</translation>
    </message>
    <message>
        <source>Are you sure you want to send?</source>
        <translation>Is u seker u wil verstuur?</translation>
    </message>
    <message>
        <source>or</source>
        <translation>of</translation>
    </message>
    <message>
        <source>You can increase the fee later (signals Replace-By-Fee, BIP-125).</source>
        <translation>U kan die fooi later verhoog (sein Vervang-met-Fooi, BIP-125)</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksie fooi</translation>
    </message>
    <message>
        <source>Not signalling Replace-By-Fee, BIP-125.</source>
        <translation>Sein nie Vervang-Met-Fooi nie, BIP-25</translation>
    </message>
    <message>
        <source>Confirm send coins</source>
        <translation>Bevestig versending van munte</translation>
    </message>
    <message>
        <source>The recipient address is not valid. Please recheck.</source>
        <translation>Die ontvangeradres is ongeldig. Kyk asseblief weer mooi.</translation>
    </message>
    <message>
        <source>The amount to pay must be larger than 0.</source>
        <translation>Bedrag moet groter as nul wees</translation>
    </message>
    <message>
        <source>The amount exceeds your balance.</source>
        <translation>Die bedrag oorskry jou saldo</translation>
    </message>
    <message>
        <source>The total exceeds your balance when the %1 transaction fee is included.</source>
        <translation>Die somtotaal oorskry jou saldo as die %1 transaksiefooi ingereken word</translation>
    </message>
    <message>
        <source>Duplicate address found: addresses should only be used once each.</source>
        <translation>Duplikaatadres: adresse behoort slegs eenkeer gebruik te word</translation>
    </message>
    <message>
        <source>Transaction creation failed!</source>
        <translation>Transaksieopstelling het gefaal</translation>
    </message>
    <message>
        <source>The transaction was rejected with the following reason: %1</source>
        <translation>Die transaksie is afgekeur met die volgende rede: %1</translation>
    </message>
    <message>
        <source>A fee higher than %1 is considered an absurdly high fee.</source>
        <translation>'n Fooi hoër as %1 word as buitensporig beskou</translation>
    </message>
    <message>
        <source>Payment request expired.</source>
        <translation>Betalings versoek verstryk.</translation>
    </message>
    <message>
        <source>Warning: Invalid Litecoin address</source>
        <translation>Waarskuwing: Ongeldige Litecoinadres</translation>
    </message>
    <message>
        <source>The address you selected for change is not part of this wallet. Any or all funds in your wallet may be sent to this address. Are you sure?</source>
        <translation>Die adres wat u gekies het vir verandering is nie deel van hierdie
beursie nie. Enige of alle fondse mag dalk daarheen gestuur word.
Is u seker?</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
</context>
<context>
    <name>SendCoinsEntry</name>
    <message>
        <source>A&amp;mount:</source>
        <translation>B&amp;edrag:</translation>
    </message>
    <message>
        <source>&amp;Label:</source>
        <translation>&amp;Etiket:</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Kies voorheen gebruikte adres</translation>
    </message>
    <message>
        <source>This is a normal payment.</source>
        <translation>Hierdie is 'n gewone betaling</translation>
    </message>
    <message>
        <source>The Litecoin address to send the payment to</source>
        <translation>Die Litecoinadres waarheen die betaling gestuur word</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Plak adres van aanknipbord af</translation>
    </message>
    <message>
        <source>Remove this entry</source>
        <translation>Verwyder hierdie inskrywing</translation>
    </message>
    <message>
        <source>The fee will be deducted from the amount being sent. The recipient will receive less litecoins than you enter in the amount field. If multiple recipients are selected, the fee is split equally.</source>
        <translation>De fooi word afgetrek van die gestuurde bedrag.
Die ontvanger sal minder ontvang as wat u in die 
bedrag opgee. As daar meer as een ontvanger is,
word die fooi eweredig verdeel.</translation>
    </message>
    <message>
        <source>S&amp;ubtract fee from amount</source>
        <translation>Bedrag &amp;Sonder fooi </translation>
    </message>
    <message>
        <source>Use available balance</source>
        <translation>Gebruik beskikbare saldo</translation>
    </message>
    <message>
        <source>Message:</source>
        <translation>Boodskap:</translation>
    </message>
    <message>
        <source>This is an unauthenticated payment request.</source>
        <translation>Hierdie is 'n ongemagtigde uitbetalingsversoek</translation>
    </message>
    <message>
        <source>This is an authenticated payment request.</source>
        <translation>Hierdie is 'n gemagtigde uitbetalingsversoek
</translation>
    </message>
    <message>
        <source>Pay To:</source>
        <translation>Betaal Vir:</translation>
    </message>
    </context>
<context>
    <name>SendConfirmationDialog</name>
    <message>
        <source>Yes</source>
        <translation>Ja</translation>
    </message>
</context>
<context>
    <name>ShutdownWindow</name>
    </context>
<context>
    <name>SignVerifyMessageDialog</name>
    <message>
        <source>&amp;Sign Message</source>
        <translation>&amp;Teken Boodskap</translation>
    </message>
    <message>
        <source>Choose previously used address</source>
        <translation>Kies voorheen gebruikte adres</translation>
    </message>
    <message>
        <source>Alt+A</source>
        <translation>Alt+A</translation>
    </message>
    <message>
        <source>Paste address from clipboard</source>
        <translation>Plak adres van aanknipbord af</translation>
    </message>
    <message>
        <source>Signature</source>
        <translation>Handtekening</translation>
    </message>
    <message>
        <source>Clear &amp;All</source>
        <translation>Vee &amp;Alles skoon</translation>
    </message>
    <message>
        <source>&amp;Verify Message</source>
        <translation>&amp;Verifieer Boodskap</translation>
    </message>
    <message>
        <source>Verify &amp;Message</source>
        <translation>Verifieer &amp;Boodskap</translation>
    </message>
    <message>
        <source>Message signed.</source>
        <translation>Boodskap geteken.</translation>
    </message>
    <message>
        <source>Message verified.</source>
        <translation>Boodskap geverifieer.</translation>
    </message>
</context>
<context>
    <name>SplashScreen</name>
    </context>
<context>
    <name>TrafficGraphWidget</name>
    <message>
        <source>KB/s</source>
        <translation>KB/s</translation>
    </message>
</context>
<context>
    <name>TransactionDesc</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>own address</source>
        <translation>eie adres</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>kyk-net</translation>
    </message>
    <message>
        <source>label</source>
        <translation>etiket</translation>
    </message>
    <message>
        <source>Credit</source>
        <translation>Krediet</translation>
    </message>
    <message>
        <source>not accepted</source>
        <translation>nie geaanvaar</translation>
    </message>
    <message>
        <source>Debit</source>
        <translation>Debiet</translation>
    </message>
    <message>
        <source>Total debit</source>
        <translation>Totale debiet</translation>
    </message>
    <message>
        <source>Total credit</source>
        <translation>Totale crediet</translation>
    </message>
    <message>
        <source>Transaction fee</source>
        <translation>Transaksie fooi</translation>
    </message>
    <message>
        <source>Net amount</source>
        <translation>Net bedrag</translation>
    </message>
    <message>
        <source>Message</source>
        <translation>Boodskap</translation>
    </message>
    <message>
        <source>Comment</source>
        <translation>Kommentaar</translation>
    </message>
    <message>
        <source>Transaction total size</source>
        <translation>Transaksie totale grootte</translation>
    </message>
    <message>
        <source>Transaction</source>
        <translation>Transaksie</translation>
    </message>
    <message>
        <source>Amount</source>
        <translation>Bedrag</translation>
    </message>
    </context>
<context>
    <name>TransactionDescDialog</name>
    </context>
<context>
    <name>TransactionTableModel</name>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>watch-only</source>
        <translation>kyk-net</translation>
    </message>
    <message>
        <source>(no label)</source>
        <translation>(geen etiket)</translation>
    </message>
    </context>
<context>
    <name>TransactionView</name>
    <message>
        <source>All</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Mined</source>
        <translation>Gemyn</translation>
    </message>
    <message>
        <source>Other</source>
        <translation>Ander</translation>
    </message>
    <message>
        <source>Copy address</source>
        <translation>Kopieer adres</translation>
    </message>
    <message>
        <source>Copy label</source>
        <translation>Kopieer etiket</translation>
    </message>
    <message>
        <source>Copy amount</source>
        <translation>Kopieer bedrag</translation>
    </message>
    <message>
        <source>Copy transaction ID</source>
        <translation>Kopieer transaksie ID</translation>
    </message>
    <message>
        <source>Comma separated file (*.csv)</source>
        <translation>Comma separated file (*.csv)</translation>
    </message>
    <message>
        <source>Confirmed</source>
        <translation>Bevestig</translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>Tipe</translation>
    </message>
    <message>
        <source>Label</source>
        <translation>Merk</translation>
    </message>
    <message>
        <source>Address</source>
        <translation>Adres</translation>
    </message>
    <message>
        <source>ID</source>
        <translation>ID</translation>
    </message>
    <message>
        <source>Exporting Failed</source>
        <translation>Uitvoer was onsuksesvol</translation>
    </message>
    <message>
        <source>to</source>
        <translation>na</translation>
    </message>
</context>
<context>
    <name>UnitDisplayStatusBarControl</name>
    </context>
<context>
    <name>WalletController</name>
    </context>
<context>
    <name>WalletFrame</name>
    </context>
<context>
    <name>WalletModel</name>
    <message>
        <source>Send Coins</source>
        <translation>Stuur Munte</translation>
    </message>
    <message>
        <source>New fee:</source>
        <translation>Nuwe fooi:</translation>
    </message>
    </context>
<context>
    <name>WalletView</name>
    <message>
        <source>&amp;Export</source>
        <translation>&amp;Voer uit</translation>
    </message>
    <message>
        <source>Export the data in the current tab to a file</source>
        <translation>Voer die inligting op hierdie bladsy uit na 'n leer</translation>
    </message>
    </context>
<context>
    <name>bitcoin-core</name>
    <message>
        <source>Litecoin Core</source>
        <translation>Litecoin Kern</translation>
    </message>
    <message>
        <source>Error loading %s</source>
        <translation>Fout met laai %s</translation>
    </message>
    <message>
        <source>Importing...</source>
        <translation>Besig met invoer...</translation>
    </message>
    <message>
        <source>Information</source>
        <translation>Inligting</translation>
    </message>
    <message>
        <source>Signing transaction failed</source>
        <translation>Teken van transaksie het misluk</translation>
    </message>
    <message>
        <source>This is experimental software.</source>
        <translation>Dié is eksperimentele sagteware.</translation>
    </message>
    <message>
        <source>Transaction amount too small</source>
        <translation>Transaksie bedrag te klein</translation>
    </message>
    <message>
        <source>Transaction too large</source>
        <translation>Transaksie te groot</translation>
    </message>
    <message>
        <source>Verifying wallet(s)...</source>
        <translation>Besig met verifieer van beursie(s)...</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Waarskuwing</translation>
    </message>
    <message>
        <source>%s is set very high!</source>
        <translation>%s is baie hoog gestel!</translation>
    </message>
    <message>
        <source>Starting network threads...</source>
        <translation>Begin tans netwerkdrade...</translation>
    </message>
    <message>
        <source>This is the minimum transaction fee you pay on every transaction.</source>
        <translation>Dit is die minimum transaksie fooi wat u betaal op elke transaksie.</translation>
    </message>
    <message>
        <source>This is the transaction fee you will pay if you send a transaction.</source>
        <translation>Dit is die transaksie fooi wat u sal betaal as u 'n transaksie stuur.</translation>
    </message>
    <message>
        <source>Transaction amounts must not be negative</source>
        <translation>Transaksies bedrae moet nie negatief wees nie</translation>
    </message>
    <message>
        <source>Transaction has too long of a mempool chain</source>
        <translation>Transaksie se mempool ketting is te lank</translation>
    </message>
    <message>
        <source>Transaction must have at least one recipient</source>
        <translation>Transaksie moet ten minste een ontvanger hê</translation>
    </message>
    <message>
        <source>Unknown network specified in -onlynet: '%s'</source>
        <translation>Onbekende netwerk gespesifiseer in -onlynet: '%s'</translation>
    </message>
    <message>
        <source>Insufficient funds</source>
        <translation>Onvoldoende fondse</translation>
    </message>
    <message>
        <source>Loading block index...</source>
        <translation>Blokindeks word gelaai...</translation>
    </message>
    <message>
        <source>Loading wallet...</source>
        <translation>Beursie word gelaai...</translation>
    </message>
    <message>
        <source>Cannot downgrade wallet</source>
        <translation>Kan nie beursie afgradeer nie</translation>
    </message>
    <message>
        <source>Rescanning...</source>
        <translation>Word herskandeer...</translation>
    </message>
    <message>
        <source>Done loading</source>
        <translation>Klaar gelaai</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
</context>
</TS>